@@ -5,11 +5,12 @@ from alira.modules.module import Module
 class Map(Module):
     def __init__(
         self,
+        module_id: str = None,
         function: str = None,
         **kwargs,
     ):
         super().__init__(
-            module_id=function,
+            module_id=module_id or function,
             **kwargs,
         )
 
